# Change log

## [1.1] - 2022-05-27

### Added
- `kenghwee.rmrf`
- `kenghwee.cs1010s`

### Changed
- Slight changes on `kenghwee.solution`
- Refactor `kenghwee.mission04`
- Modify dependencies

### Removed

## [1.0] - 2022-05-26

### Added
- `kenghwee.solution`
- `kenghwee.mission04`

### Changed

### Removed